==> jc-1.4.0.tar.gz: java__5fcup/version.h <==
// public class java_cup.version

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 70889993eed89c86 java__5fcup_version

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java__5fcup_version_H_
#define _JC_java__5fcup_version_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java__5fcup_version$sub_refs	_jc_java__5fcup_version$sub_refs;
typedef struct _jc_java__5fcup_version$sub_nonrefs	_jc_java__5fcup_version$sub_nonrefs;
typedef struct _jc_java__5fcup_version$refs	_jc_java__5fcup_version$refs;
typedef struct _jc_java__5fcup_version$nonrefs	_jc_java__5fcup_version$nonrefs;
typedef struct _jc_java__5fcup_version$object	_jc_java__5fcup_version$object;

typedef struct _jc_java__5fcup_version$fields_struct	_jc_java__5fcup_version$fields_struct;
typedef const struct _jc_java__5fcup_version$vmethods	_jc_java__5fcup_version$vmethods;
typedef const struct _jc_java__5fcup_version$vtable	_jc_java__5fcup_version$vtable;
typedef const struct _jc_java__5fcup_version$vtype	_jc_java__5fcup_version$vtype;

// Class fields structure
struct _jc_java__5fcup_version$fields_struct {
	struct _jc_java_lang_String$object	*author__5fstr;
	struct _jc_java_lang_String$object	*program__5fname;
	struct _jc_java_lang_String$object	*title__5fstr;
	struct _jc_java_lang_String$object	*version__5fstr;
	jint	major;
	jint	minor;
	jchar	update;
};
extern _jc_java__5fcup_version$fields_struct _jc_java__5fcup_version$class_fields;

// Constructors
extern void _jc_java__5fcup_version$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java__5fcup_version$object *);

// Virtual methods structure
struct _jc_java__5fcup_version$vmethods {
};

// Vtable
struct _jc_java__5fcup_version$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java__5fcup_version$vmethods	java__5fcup_version;
};

// Vtype
struct _jc_java__5fcup_version$vtype {
	_jc_type			type;
	_jc_java__5fcup_version$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_version$sub_refs {
};

// Reference instance fields (object)
struct _jc_java__5fcup_version$refs {
    _jc_java__5fcup_version$sub_refs	java__5fcup_version;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_version$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_version$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java__5fcup_version$sub_nonrefs	java__5fcup_version;
};

// Object instance structure
struct _jc_java__5fcup_version$object {
	_jc_java__5fcup_version$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_version$vtype	*vtype;
	_jc_java__5fcup_version$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_version$vtype _jc_java__5fcup_version$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_version, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_version$class_object;

#endif	/* _JC_java__5fcup_version_H_ */

==> jc-1.4.6.tar.gz: java__5fcup/version.h <==
// public class java_cup.version

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 70889993eed89c86 java__5fcup_version

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java__5fcup_version_H_
#define _JC_java__5fcup_version_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java__5fcup_version$sub_refs	_jc_java__5fcup_version$sub_refs;
typedef struct _jc_java__5fcup_version$sub_nonrefs	_jc_java__5fcup_version$sub_nonrefs;
typedef struct _jc_java__5fcup_version$refs	_jc_java__5fcup_version$refs;
typedef struct _jc_java__5fcup_version$nonrefs	_jc_java__5fcup_version$nonrefs;
typedef struct _jc_java__5fcup_version$object	_jc_java__5fcup_version$object;

typedef struct _jc_java__5fcup_version$fields_struct	_jc_java__5fcup_version$fields_struct;
typedef const struct _jc_java__5fcup_version$vmethods	_jc_java__5fcup_version$vmethods;
typedef const struct _jc_java__5fcup_version$vtable	_jc_java__5fcup_version$vtable;
typedef const struct _jc_java__5fcup_version$vtype	_jc_java__5fcup_version$vtype;

// Class fields structure
struct _jc_java__5fcup_version$fields_struct {
	struct _jc_java_lang_String$object	*author__5fstr;
	struct _jc_java_lang_String$object	*program__5fname;
	struct _jc_java_lang_String$object	*title__5fstr;
	struct _jc_java_lang_String$object	*version__5fstr;
	jint	major;
	jint	minor;
	jchar	update;
};
extern _jc_java__5fcup_version$fields_struct _jc_java__5fcup_version$class_fields;

// Constructors
extern void _jc_java__5fcup_version$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java__5fcup_version$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java__5fcup_version$vmethods {
};

// Vtable
struct _jc_java__5fcup_version$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java__5fcup_version$vmethods	java__5fcup_version;
};

// Vtype
struct _jc_java__5fcup_version$vtype {
	_jc_type			type;
	_jc_java__5fcup_version$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_version$sub_refs {
};

// Reference instance fields (object)
struct _jc_java__5fcup_version$refs {
    _jc_java__5fcup_version$sub_refs	java__5fcup_version;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_version$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_version$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java__5fcup_version$sub_nonrefs	java__5fcup_version;
};

// Object instance structure
struct _jc_java__5fcup_version$object {
	_jc_java__5fcup_version$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_version$vtype	*vtype;
	_jc_java__5fcup_version$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_version$vtype _jc_java__5fcup_version$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_version, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_version$class_object;

#endif	/* _JC_java__5fcup_version_H_ */
